# -*- coding: utf-8 -*-
"""
Created on Mon Nov 13 11:00:23 2023

@author: s168562
"""

# Packages
import numpy as np
import matplotlib.pyplot as plt
import os
import pandas as pd

# Input
outpathfull = r"C:\Users\s168562\OneDrive - TU Eindhoven\PhD\7_LCN-GR gripper manuscript\Figures\Fig 2 heat\Temperature vs voltage (model and experiment)"
# sample = "LH-GN24-2000g-dowanol" # sample name as will be added to output
filepath = r"C:\Users\s168562\OneDrive - TU Eindhoven\PhD\7_LCN-GR gripper manuscript\Figures\Fig 2 heat\Temperature vs voltage (model and experiment)" # r to escape the backslashes
filename_exp = "Experimental T vs V.csv"
filename_model = "Model t vs V.csv"

# Plot preliminaries
plt.style.use('default') # default, ggplot, seaborn-*, dark_background, fivethirtyeight
plt.rcParams['font.size'] = 8 # set plot font size matplotlib
cm = 1/2.54  # convert centimeters to inches
cbPalVivid_correctorder = ["#999999", "#AF1B3F", "#F4A698", "#262626", "#6BAA75", "#255C99", "#7EA3CC"]
cbPalVivid = ["#999999", "#AF1B3F", "#F4A698", "#255C99", "#7EA3CC", "#262626", "#6BAA75"]
TUred = "#C81919"
pinkish = "#DE8787"
redish = "#EC1C24"

## set color map (only works when first manually running the script palettes.py stored here:)
# C:\Users\s168562\OneDrive - TU Eindhoven\PhD\Code general\MetBrewer-main\MetBrewer-main\Python\met_brewer
colormap = met_brew(name="Cassatt2", n=10, brew_type="continuous")
colormap = met_brew(name="Hokusai", n=6, brew_type="continuous")
colormap = met_brew(name="Okeeffe1", n=11, brew_type="continuous") # also try in reverse
colormap = met_brew(name="Okeeffe2", n=7, brew_type="continuous")
colormap = met_brew(name="VanGogh3", n=8, brew_type="continuous")
colormap = met_brew(name="Troy", n=8, brew_type="continuous") # also try in reverse
colormap = met_brew(name="Hiroshige", n=10, brew_type="continuous") # also try in reverse
colormap = met_brew(name="Tam", n=5, brew_type="continuous") # looks a bit like a heat map

if not os.path.exists(outpathfull):
    os.makedirs(outpathfull)

# Read data
fullpath_exp = os.path.join(filepath,filename_exp)
fullpath_model = os.path.join(filepath,filename_model)
df_exp = pd.read_csv(fullpath_exp, skiprows = 1, sep=";", decimal= ",", header = None)   
df_model = pd.read_csv(fullpath_model, skiprows = 1, sep=";", decimal= ",", header = None)    
df_exp.columns = ["V", "T_avg", "T_std"]
df_model.columns = ["V", "T"]

# Plot
plt.figure(figsize= [5.5*cm, 3.8*cm])
ax = plt.axes()
# plt.scatter(df_exp['V'], df_exp["T_avg"], color = redish, marker = "o", s = 15,
#             label = "Experiment")
# plt.errorbar(df_exp['V'], df_exp["T_avg"], yerr = df_exp["T_std"], fmt = "none", ecolor = redish,
#               elinewidth = 1.5, capsize = 2)
plt.scatter(df_exp['V'], df_exp["T_avg"], color = colormap[2], marker = "o", s = 15,
            label = "Experiment")
plt.errorbar(df_exp['V'], df_exp["T_avg"], yerr = df_exp["T_std"], fmt = "none", ecolor = colormap[2],
              elinewidth = 1.5, capsize = 2)
plt.plot(df_model['V'], df_model["T"], color = "black", label = "Model") # TUred
# plt.xscale('log')
ax.tick_params(axis="both",direction="in", left="off",labelleft="on", right = "on",
               top = "on")
# ax.set_xticks([10, 100, 1000, 10000])
ax.set_xlim(-1,21)
ax.set_ylim(18, 82)
# for axis in [ax.xaxis, ax.yaxis]:
#     axis.set_major_formatter(ScalarFormatter())
ax.set_facecolor("white")
# plt.legend("Experiment", "Model")
ax.legend(loc='upper left', fontsize = 'small',
          frameon = False)
plt.xlabel(r'Voltage [V]')
plt.ylabel(r'Temperature [$^\circ$C]') # r'Probability'
figurepath_pdf = os.path.join(outpathfull, "TvsV.pdf")
figurepath_tiff = os.path.join(outpathfull, "TvsV.tiff")
plt.savefig(figurepath_tiff, dpi = 300, bbox_inches='tight', transparent = True)
plt.savefig(figurepath_pdf, dpi = 300, bbox_inches='tight', transparent = True)
plt.show()